PasswordStrengthConfig class
Constructors
Properties
-
barColors
→ List<
Color> -
final
-
emojis
→ List<
String> -
final
- emojiSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ List<
String> -
final
- labelStyle → TextStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTips → bool
-
final
- tipStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited